# Changelog

## [0.3.1] - 2021-02-07
- Fixed older Python 3 version compatability.

## [0.3.0] - 2021-02-07
- Added support for older versions of Python (3.1)
- Added label editing with F1 or CTRL+E

## [0.2.3] - 2021-02-07
- Fixed detection of shell for command execution.

## [0.2.2] - 2021-02-07
- Fixed crash when deleting non-existant items.
- Fixed detection of BACKSPACE key in some environments.

## [0.2.1] - 2021-02-07

- Removed dependency on Python 3.9 features.
- Added Changelog.

## [0.2.0] - 2021-02-07

- Initial release.